datastructuretools.PayloadTree
==============================

.. abjad-lineage:: abjad.tools.datastructuretools.PayloadTree.PayloadTree

.. autoclass:: abjad.tools.datastructuretools.PayloadTree.PayloadTree

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.datastructuretools.PayloadTree.PayloadTree.children
      ~abjad.tools.datastructuretools.PayloadTree.PayloadTree.depth
      ~abjad.tools.datastructuretools.PayloadTree.PayloadTree.expr
      ~abjad.tools.datastructuretools.PayloadTree.PayloadTree.get_manifest_payload_of_next_n_nodes_at_level
      ~abjad.tools.datastructuretools.PayloadTree.PayloadTree.get_next_n_complete_nodes_at_level
      ~abjad.tools.datastructuretools.PayloadTree.PayloadTree.get_next_n_nodes_at_level
      ~abjad.tools.datastructuretools.PayloadTree.PayloadTree.get_node_at_position
      ~abjad.tools.datastructuretools.PayloadTree.PayloadTree.get_position_of_descendant
      ~abjad.tools.datastructuretools.PayloadTree.PayloadTree.graphviz_format
      ~abjad.tools.datastructuretools.PayloadTree.PayloadTree.graphviz_graph
      ~abjad.tools.datastructuretools.PayloadTree.PayloadTree.improper_parentage
      ~abjad.tools.datastructuretools.PayloadTree.PayloadTree.index
      ~abjad.tools.datastructuretools.PayloadTree.PayloadTree.index_in_parent
      ~abjad.tools.datastructuretools.PayloadTree.PayloadTree.is_at_level
      ~abjad.tools.datastructuretools.PayloadTree.PayloadTree.item_class
      ~abjad.tools.datastructuretools.PayloadTree.PayloadTree.iterate_at_level
      ~abjad.tools.datastructuretools.PayloadTree.PayloadTree.iterate_depth_first
      ~abjad.tools.datastructuretools.PayloadTree.PayloadTree.iterate_payload
      ~abjad.tools.datastructuretools.PayloadTree.PayloadTree.level
      ~abjad.tools.datastructuretools.PayloadTree.PayloadTree.manifest_payload
      ~abjad.tools.datastructuretools.PayloadTree.PayloadTree.negative_level
      ~abjad.tools.datastructuretools.PayloadTree.PayloadTree.payload
      ~abjad.tools.datastructuretools.PayloadTree.PayloadTree.position
      ~abjad.tools.datastructuretools.PayloadTree.PayloadTree.proper_parentage
      ~abjad.tools.datastructuretools.PayloadTree.PayloadTree.remove_node
      ~abjad.tools.datastructuretools.PayloadTree.PayloadTree.remove_to_root
      ~abjad.tools.datastructuretools.PayloadTree.PayloadTree.root
      ~abjad.tools.datastructuretools.PayloadTree.PayloadTree.to_nested_lists
      ~abjad.tools.datastructuretools.PayloadTree.PayloadTree.width
      ~abjad.tools.datastructuretools.PayloadTree.PayloadTree.__contains__
      ~abjad.tools.datastructuretools.PayloadTree.PayloadTree.__eq__
      ~abjad.tools.datastructuretools.PayloadTree.PayloadTree.__format__
      ~abjad.tools.datastructuretools.PayloadTree.PayloadTree.__getitem__
      ~abjad.tools.datastructuretools.PayloadTree.PayloadTree.__hash__
      ~abjad.tools.datastructuretools.PayloadTree.PayloadTree.__len__
      ~abjad.tools.datastructuretools.PayloadTree.PayloadTree.__ne__
      ~abjad.tools.datastructuretools.PayloadTree.PayloadTree.__repr__

Bases
-----

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject>`

- :py:class:`abctools.AbjadObject.AbstractBase <abjad.tools.abctools.AbjadObject.AbstractBase>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.datastructuretools.PayloadTree.PayloadTree.children
   :noindex:

.. autoattribute:: abjad.tools.datastructuretools.PayloadTree.PayloadTree.depth
   :noindex:

.. autoattribute:: abjad.tools.datastructuretools.PayloadTree.PayloadTree.expr
   :noindex:

.. autoattribute:: abjad.tools.datastructuretools.PayloadTree.PayloadTree.graphviz_format
   :noindex:

.. autoattribute:: abjad.tools.datastructuretools.PayloadTree.PayloadTree.graphviz_graph
   :noindex:

.. autoattribute:: abjad.tools.datastructuretools.PayloadTree.PayloadTree.improper_parentage
   :noindex:

.. autoattribute:: abjad.tools.datastructuretools.PayloadTree.PayloadTree.index_in_parent
   :noindex:

.. autoattribute:: abjad.tools.datastructuretools.PayloadTree.PayloadTree.item_class
   :noindex:

.. autoattribute:: abjad.tools.datastructuretools.PayloadTree.PayloadTree.level
   :noindex:

.. autoattribute:: abjad.tools.datastructuretools.PayloadTree.PayloadTree.manifest_payload
   :noindex:

.. autoattribute:: abjad.tools.datastructuretools.PayloadTree.PayloadTree.negative_level
   :noindex:

.. autoattribute:: abjad.tools.datastructuretools.PayloadTree.PayloadTree.payload
   :noindex:

.. autoattribute:: abjad.tools.datastructuretools.PayloadTree.PayloadTree.position
   :noindex:

.. autoattribute:: abjad.tools.datastructuretools.PayloadTree.PayloadTree.proper_parentage
   :noindex:

.. autoattribute:: abjad.tools.datastructuretools.PayloadTree.PayloadTree.root
   :noindex:

.. autoattribute:: abjad.tools.datastructuretools.PayloadTree.PayloadTree.width
   :noindex:

Methods
-------

.. automethod:: abjad.tools.datastructuretools.PayloadTree.PayloadTree.get_manifest_payload_of_next_n_nodes_at_level
   :noindex:

.. automethod:: abjad.tools.datastructuretools.PayloadTree.PayloadTree.get_next_n_complete_nodes_at_level
   :noindex:

.. automethod:: abjad.tools.datastructuretools.PayloadTree.PayloadTree.get_next_n_nodes_at_level
   :noindex:

.. automethod:: abjad.tools.datastructuretools.PayloadTree.PayloadTree.get_node_at_position
   :noindex:

.. automethod:: abjad.tools.datastructuretools.PayloadTree.PayloadTree.get_position_of_descendant
   :noindex:

.. automethod:: abjad.tools.datastructuretools.PayloadTree.PayloadTree.index
   :noindex:

.. automethod:: abjad.tools.datastructuretools.PayloadTree.PayloadTree.is_at_level
   :noindex:

.. automethod:: abjad.tools.datastructuretools.PayloadTree.PayloadTree.iterate_at_level
   :noindex:

.. automethod:: abjad.tools.datastructuretools.PayloadTree.PayloadTree.iterate_depth_first
   :noindex:

.. automethod:: abjad.tools.datastructuretools.PayloadTree.PayloadTree.iterate_payload
   :noindex:

.. automethod:: abjad.tools.datastructuretools.PayloadTree.PayloadTree.remove_node
   :noindex:

.. automethod:: abjad.tools.datastructuretools.PayloadTree.PayloadTree.remove_to_root
   :noindex:

.. automethod:: abjad.tools.datastructuretools.PayloadTree.PayloadTree.to_nested_lists
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.datastructuretools.PayloadTree.PayloadTree.__contains__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.PayloadTree.PayloadTree.__eq__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.PayloadTree.PayloadTree.__format__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.PayloadTree.PayloadTree.__getitem__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.PayloadTree.PayloadTree.__hash__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.PayloadTree.PayloadTree.__len__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.PayloadTree.PayloadTree.__ne__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.PayloadTree.PayloadTree.__repr__
   :noindex:
